require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cluster',
  dscmeta_resource_friendly_name: 'Cluster',
  dscmeta_resource_name: 'DSC_Cluster',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'FailoverClusterDsc',
  dscmeta_module_version: '2.1.0',
  docs: 'The DSC Cluster resource type.
         Automatically generated from version 2.1.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ignorenetwork: {
      type: 'Optional[Array[String]]',
      desc: 'One or more networks to ignore when creating the cluster. Only networks using Static IP can be ignored, networks that are assigned an IP address through DHCP cannot be ignored, and are added for cluster communication. To remove networks assigned an IP address through DHCP use the resource ClusterNetwork to change the role of the network. This parameter is only used during the creation of the cluster and is not monitored after.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_domainadministratorcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential used to create the failover cluster in Active Directory. If this is not specified then the cluster computer object must have been prestaged as per the [documentation](https://docs.microsoft.com/en-us/windows-server/failover-clustering/prestage-cluster-adds). If `PsDscRunAsCredential` is used, then that account must have been granted Full Control over the Cluster Name Object in Active Directory. Otherwise the Computer Account must have been granted Full Control over the Cluster Name Object in Active Directory.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_keepdownednodesincluster: {
      type: 'Optional[Boolean]',
      desc: 'Switch controlling whether or not to evict cluster nodes in a down state from the cluster. Default value is `$false`.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the failover cluster.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_staticipaddress: {
      type: 'Optional[String]',
      desc: 'The static IP address of the failover cluster. If this is not specified then the IP address will be assigned from a DHCP.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
