require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_clusternetwork',
  dscmeta_resource_friendly_name: 'ClusterNetwork',
  dscmeta_resource_name: 'DSC_ClusterNetwork',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'FailoverClusterDsc',
  dscmeta_module_version: '2.1.0',
  docs: 'The DSC ClusterNetwork resource type.
         Automatically generated from version 2.1.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_addressmask: {
      type: 'String',
      desc: "The address mask for the cluster network in the format `'255.255.255.0'`.",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_metric: {
      type: 'Optional[String]',
      desc: 'The metric number for the cluster network. If the cluster network metric number is not in desired state it will be changed to match this metric number.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_role: {
      type: "Optional[Enum['0', '1', '3']]",
      desc: 'The role of the cluster network. If the cluster network role is not in desired state it will change to match this role.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'Optional[String]',
      desc: 'The name of the cluster network. If the cluster network name is not in desired state it will be renamed to match this name.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_address: {
      type: 'String',
      desc: "The address for the cluster network in the format `'10.0.0.0'`.",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
