require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_clusterpreferredowner',
  dscmeta_resource_friendly_name: 'ClusterPreferredOwner',
  dscmeta_resource_name: 'DSC_ClusterPreferredOwner',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'FailoverClusterDsc',
  dscmeta_module_version: '2.1.0',
  docs: 'The DSC ClusterPreferredOwner resource type.
         Automatically generated from version 2.1.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_clustername: {
      type: 'String',
      desc: 'Name of the cluster.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: "If the preferred owners should be present or absent. Default value is `'Present'`.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_nodes: {
      type: 'Array[String]',
      desc: 'The nodes to set as owners.',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_clustergroup: {
      type: 'String',
      desc: 'Name of the cluster group.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clusterresources: {
      type: 'Optional[Array[String]]',
      desc: 'The resources to set preferred owners on.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
